>From 5f9d96f8827ffa96643beba1e4ca0f3ebe2510b4 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Filip=20Ros=C3=A9en?= <filip@atch.se>
Date: Sun, 30 Oct 2016 23:33:25 +0100
Subject: [PATCH 4/4] demux/nsv: do not read chunks greater than SSIZE_MAX

On a 32-bit platform, SSIZE_MAX is generally smaller than UINT32_MAX,
meaning that invoking vlc_stream_Read where the size argument is
UINT32_MAX makes it impossible for vlc_stream_Read to signal that the
reading was successful.

These changes reads data in chunks of at most SSIZE_MAX to prevent the
previously described issue.
---
 modules/demux/nsv.c | 14 ++++++++++++--
 1 file changed, 12 insertions(+), 2 deletions(-)

diff --git a/modules/demux/nsv.c b/modules/demux/nsv.c
index fc260f9..2421664 100644
--- a/modules/demux/nsv.c
+++ b/modules/demux/nsv.c
@@ -32,6 +32,7 @@
 #include <vlc_common.h>
 #include <vlc_plugin.h>
 #include <vlc_demux.h>
+#include <limits.h>
 
 /* TODO:
  *  - implement NSVf parsing (to get meta data)
@@ -459,9 +460,18 @@ static int ReadNSVf( demux_t *p_demux )
     if( i_header_size == 0 || i_header_size == UINT32_MAX )
         return VLC_EGENERIC;
 
+    for( ssize_t i_req; i_header_size; i_header_size -= i_req )
+    {
+#if SSIZE_MAX < UINT32_MAX
+        i_req = __MIN( SSIZE_MAX, i_header_size );
+#else
+        i_req = i_header_size;
+#endif
+        if( vlc_stream_Read( p_demux->s, NULL, i_req ) != i_req )
+            return VLC_EGENERIC;
+    }
 
-    return vlc_stream_Read( p_demux->s, NULL, i_header_size ) == i_header_size
-        ? VLC_SUCCESS : VLC_EGENERIC;
+    return VLC_SUCCESS;
 }
 /*****************************************************************************
  * ReadNSVs:
-- 
2.10.1

